﻿using MediatR;
using Microsoft.EntityFrameworkCore;
using Mirea.Api.DataAccess.Application.Interfaces.DbContexts.Schedule;
using System.Linq;
using System.Threading;
using System.Threading.Tasks;

namespace Mirea.Api.DataAccess.Application.Cqrs.Professor.Queries.GetProfessorList;

public class GetProfessorListQueryHandler(IProfessorDbContext dbContext) : IRequestHandler<GetProfessorListQuery, ProfessorListVm>
{
    public async Task<ProfessorListVm> Handle(GetProfessorListQuery request, CancellationToken cancellationToken)
    {
        var dtos = dbContext.Professors.OrderBy(p => p.Id).Select(p => new ProfessorLookupDto()
        {
            Id = p.Id,
            Name = p.Name,
            AltName = p.AltName
        });

        if (request is { PageSize: not null, Page: not null })
            dtos = dtos.Skip(request.Page.Value * request.PageSize.Value).Take(request.PageSize.Value);

        var result = await dtos.ToListAsync(cancellationToken);

        return new ProfessorListVm
        {
            Professors = result
        };
    }
}