﻿using System;
using System.Collections.Generic;

namespace Mirea.Api.DataAccess.Application.Cqrs.Schedule.Queries.GetScheduleList;

/// <summary>
/// Represents a data transfer object for schedule lookup.
/// </summary>
public class ScheduleLookupDto
{
    /// <summary>
    /// Gets or sets the day of the week.
    /// </summary>
    public DayOfWeek DayOfWeek { get; set; }

    /// <summary>
    /// Gets or sets the pair number.
    /// </summary>
    public int PairNumber { get; set; }

    /// <summary>
    /// Gets or sets a value indicating whether the pair is on an even week.
    /// </summary>
    public bool IsEven { get; set; }

    /// <summary>
    /// Gets or sets the name of the discipline.
    /// </summary>
    public required string Discipline { get; set; }

    /// <summary>
    /// Gets or sets the ID of the discipline.
    /// </summary>
    public required int DisciplineId { get; set; }

    /// <summary>
    /// Gets or sets exclude or include weeks for a specific discipline.
    /// </summary>
    public bool? IsExcludedWeeks { get; set; }

    /// <summary>
    /// The week numbers required for the correct display of the schedule.
    /// </summary>
    public IEnumerable<int>? Weeks { get; set; }

    /// <summary>
    /// Gets or sets the name of the group.
    /// </summary>
    public required string Group { get; set; }

    /// <summary>
    /// Gets or sets the ID of the group.
    /// </summary>
    public required int GroupId { get; set; }

    /// <summary>
    /// Gets or sets the type of occupation.
    /// </summary>
    public required IEnumerable<string> TypeOfOccupations { get; set; }

    /// <summary>
    /// Gets or sets the names of the lecture halls.
    /// </summary>
    public required IEnumerable<string?> LectureHalls { get; set; }

    /// <summary>
    /// Gets or sets the IDs of the lecture halls.
    /// </summary>
    public required IEnumerable<int?> LectureHallsId { get; set; }

    /// <summary>
    /// Gets or sets the names of the professors.
    /// </summary>
    public required IEnumerable<string?> Professors { get; set; }

    /// <summary>
    /// Gets or sets the IDs of the professors.
    /// </summary>
    public required IEnumerable<int?> ProfessorsId { get; set; }

    /// <summary>
    /// Gets or sets the names of the campuses.
    /// </summary>
    public required IEnumerable<string?> Campus { get; set; }

    /// <summary>
    /// Gets or sets the IDs of the campuses.
    /// </summary>
    public required IEnumerable<int?> CampusId { get; set; }

    /// <summary>
    /// Gets or sets the links to online meetings.
    /// </summary>
    public required IEnumerable<string?> LinkToMeet { get; set; }
}