﻿using Microsoft.EntityFrameworkCore;
using Microsoft.EntityFrameworkCore.Metadata.Builders;
using Mirea.Api.DataAccess.Domain.Schedule;

namespace Mirea.Api.DataAccess.Persistence.EntityTypeConfigurations.Schedule;

public class LectureHallConfiguration : IEntityTypeConfiguration<LectureHall>
{
    public void Configure(EntityTypeBuilder<LectureHall> builder)
    {
        builder.ToTable(nameof(LectureHall));
        builder.HasKey(l => l.Id);
        builder.HasIndex(l => l.Id).IsUnique();
        builder.Property(l => l.Id).HasColumnType("INTEGER").IsRequired().ValueGeneratedOnAdd();

        builder.Property(l => l.CampusId).HasColumnType("INTEGER").IsRequired();
        builder.Property(l => l.Name).HasColumnType("TEXT").IsRequired().HasMaxLength(64);

        builder
            .HasOne(l => l.Campus)
            .WithMany(c => c.LectureHalls)
            .HasForeignKey(d => d.CampusId)
            .OnDelete(DeleteBehavior.Restrict);
    }
}